import React, { useState, useEffect } from 'react'
import { Client, withClient } from 'cozy-client'
import { translate } from 'cozy-ui/react/I18n'

import { Konnector } from 'doctypes'
import KonnectorService from 'services/konnectorService'

import { OAuthWindow } from 'cozy-harvest-lib/dist/components/OAuthWindow'

import StyledButton from 'components/CommonKit/Button/StyledButton'

interface OAuthFormProps {
  konnector: Konnector
  onSuccess: Function
  client: Client
  t: Function
}

const OAuthForm: React.FC<OAuthFormProps> = ({
  konnector,
  onSuccess,
  client,
  t,
}: OAuthFormProps) => {
  const IDLE = 'idle'
  const WAITING = 'waiting'

  const [status, setStatus] = useState<string>(IDLE)

  function endOAuth() {
    setStatus(IDLE)
  }
  function startOAuth() {
    setStatus(WAITING)
  }
  function handleAccountId(accountId: string) {
    endOAuth()
    onSuccess(accountId)
  }
  function handleSubmit() {
    startOAuth()
  }
  function handleOAuthCancel() {
    endOAuth()
  }

  const isWaiting = status === WAITING
  return !konnector ? null : (
    <>
      <StyledButton
        type="button"
        color="primary"
        onClick={handleSubmit}
        disabled={isWaiting}
      >
        {t('oauth.connect.label')}
      </StyledButton>
      {isWaiting && (
        <OAuthWindow
          client={client}
          konnector={konnector}
          onSuccess={handleAccountId}
          onCancel={handleOAuthCancel}
          t={t}
        />
      )}
    </>
  )
}

export default translate()(withClient(OAuthForm))
